@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Base routines
 #
-# $Id: LONCAPA.pm,v 1.23 2007/01/10 20:22:30 albertel Exp $
+# $Id: LONCAPA.pm,v 1.24 2007/07/02 21:15:29 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -113,8 +113,8 @@ sub clean_domain {
     return $domain;
 }
 
-$match_username     = $LONCAPA::username_re     = qr{\w[\w\-.]+};
-$match_not_username = $LONCAPA::not_username_re = qr{[^\w\-.]+};
+$match_username     = $LONCAPA::username_re     = qr{\w[\w\-.@]+};
+$match_not_username = $LONCAPA::not_username_re = qr{[^\w\-.@]+};
 sub clean_username {
     my ($username) = @_;
     $username =~ s/^\W+//;
@@ -148,8 +148,8 @@ sub split_courseid {
     return ($domain,$coursenum);
 }
 
-$match_handle     = $LONCAPA::handle_re     = qr{[\w\-.]+};
-$match_not_handle = $LONCAPA::not_handle_re = qr{[^\w\-.]+};
+$match_handle     = $LONCAPA::handle_re     = qr{[\w\-.@]+};
+$match_not_handle = $LONCAPA::not_handle_re = qr{[^\w\-.@]+};
 sub clean_handle {
     my ($handle) = @_;
     $handle =~ s/$match_not_handle//g;
