@@ -1,5 +1,5 @@
 #
-# $Id: batchcreatecourse.pm,v 1.19 2006/12/20 22:35:35 albertel Exp $
+# $Id: batchcreatecourse.pm,v 1.21 2007/05/11 01:48:26 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -32,6 +32,7 @@ use Time::Local;
 use Apache::lonnet;
 use Apache::loncommon;
 use Apache::lonlocal;
+use LONCAPA qw(:match);
 
 use strict;
 
@@ -218,7 +219,9 @@ sub create_courses {
                 &parse_coursereqs($newcoursedir.'/'.$request, \%details);
                 foreach my $num (sort keys %details) {
                     my $courseid = &build_course($dom,$num,$context,\%details,\%longroles,\$logmsg,\$newusermsg,\$addresult,\%enrollcount,\$output,\$keysmsg);
-                    $$courseids{$courseid} = $details{$num}{'class'};
+                    if ($courseid =~ /^$match_courseid$/) {
+                        $$courseids{$courseid} = $details{$num}{'class'};
+                    }
                 }
             }
         }
@@ -489,7 +492,7 @@ sub build_course {
                firstres => $firstres
                };
 
-        my %host_servers = &Apache::loncommon::get_library_servers($cdom);
+        my %host_servers = &Apache::lonnet::get_servers($cdom,'library');
         if (! exists($host_servers{$$details{$num}{'coursehome'}})) {
             $$logmsg .= &mt('Invalid home server for course').': '.$$details{$num}{'coursehome'};
             return;
