@@ -1,7 +1,7 @@
 # LearningOnline Network with CAPA
 # option list style responses
 #
-# $Id: optionresponse.pm,v 1.135 2006/03/15 17:10:49 albertel Exp $
+# $Id: optionresponse.pm,v 1.143 2007/04/17 23:25:09 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -183,8 +183,10 @@ sub end_foilgroup {
 					       $safeeval,'-2');
     if ($target eq 'web' || $target eq 'tex') {
       $result.=&displayfoils($target,$max,$randomize,$TeXlayout,@opt);
+      $Apache::lonxml::post_evaluate=0;
     } elsif ( $target eq 'answer') {
       $result.=&displayanswers($max,$randomize,@opt);
+      
     } elsif ( $target eq 'analyze') {
 	my @shown = &whichfoils($max,$randomize);
 	&Apache::response::analyze_store_foilgroup(\@shown,
@@ -421,7 +423,8 @@ sub displayfoils {
       }
       if ($target ne 'tex') {
 	  if ($Apache::lonhomework::type ne 'exam') {
-	      $optionlist='<select name="HWVAL_'.
+	      $optionlist='<select onchange="javascript:setSubmittedPart(\''.
+		  $part.'\');" name="HWVAL_'.
 		  $Apache::inputtags::response['-1'].':'.$temp.'">'.
 		  $optionlist."</select>\n";
 	  } else {
@@ -448,7 +451,7 @@ sub displayfoils {
 	      $texoptionlist = &optionlist_correction($TeXlayout,@opt);
 	  }
 	  if ($text=~/<drawoptionlist\s*\/>/) {
-	      $text=~s|<drawoptionlist\s*/>| \\makebox\[0\.3in\]\[b\]\{\\hrulefill\} |;
+	      $text=~s|<drawoptionlist\s*\/>| \\makebox\[0\.3in\]\[b\]\{\\hrulefill\} |g;
 	  }
 
 	  if ($text=~m/\\item /) {
@@ -473,6 +476,13 @@ sub displayfoils {
       }
     }
   }
+
+  if ($target eq 'web') {
+      &Apache::response::setup_prior_tries_hash(\&Apache::rankresponse::format_prior_answer,
+						[\@whichopt,
+						 'submissiongrading']);
+  }
+
   if ($target ne 'tex') {
       return $result.$break;
   } else {
@@ -531,25 +541,32 @@ sub webbubbles {
 
 
 sub bubbles {
-    my ($ralphabet,$ropt,$response) = @_;
+    my ($ralphabet,$ropt,$response, $max_width) = @_;
     my @alphabet = @$ralphabet;
     my @opt = @$ropt;
     my ($result,$head,$line) =('','','');
     my $number_of_bubbles = $#opt + 1;
     my $current_length = 0;
     my $textwidth;
-    if ($env{'form.textwidth'} ne '') {
+    if (defined($max_width)) {
+	$textwidth=$max_width;
+	&Apache::lonxml::debug("Max width passed in: $max_width");
+    } elsif ($env{'form.textwidth'} ne '') {
 	$env{'form.textwidth'}=~/(\d+)/;
 	$textwidth=$1;
+	&Apache::lonxml::debug("Max width from form: $textwidth");
     } else {
 	$env{'form.textwidth'}=~/(\d*)\.?(\d*)/;
 	$textwidth=$1.'.'.$2;
+	&Apache::lonxml::debug("Max width defaults? $textwidth");
     }
+    &Apache::lonxml::debug("Final maxwidth: $textwidth");
     for (my $ind=0;$ind<=$number_of_bubbles;$ind++) {
 	my $leftmargin;
 	$opt[$ind]=&Apache::lonxml::latex_special_symbols($opt[$ind]);
 	if ($response eq 'rankresponse') {$opt[$ind]='Rank '.$opt[$ind];}
 	if ($ind==0) {$leftmargin=6;} else {$leftmargin=10;}
+
 	$current_length += (length($opt[$ind])+length($alphabet[$ind])+4)*2;
 	if ($current_length<($textwidth-$leftmargin) and $ind!=$number_of_bubbles) {
 	    $line.='\hskip -1 mm {\small \textbf{'.$alphabet[$ind].'}}$\bigcirc$\hskip -1 mm & \hskip -3 mm {\small '.$opt[$ind].'} & ';
@@ -688,14 +705,14 @@ sub end_foil {
 
 sub start_drawoptionlist {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
-    if ($target ne 'meta') {
+    if (($target ne 'meta')  && ($target ne 'answer')) {
 	return $token->[4];
     }
 }
 
 sub end_drawoptionlist {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
-    if ($target ne 'meta') {
+    if (($target ne 'meta') && ($target ne 'answer')) {
 	return $token->[2];
     }
 }
