@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # random labelling tool
 #
-# $Id: randomlabel.pm,v 1.85 2006/11/07 02:39:58 albertel Exp $
+# $Id: randomlabel.pm,v 1.88 2007/05/23 22:36:21 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -70,7 +70,7 @@ my $cgi_id;
 my $scale_factor;		# image scale factor.
 my $label_xscale;                # Label scale factor (needed for gnuplot).
 my $label_yscale;
-
+my $dirty_width_adjust = 5;     # Width adjustment for e.g. gnuplot images.
 
 BEGIN {
     &Apache::lonxml::register('Apache::randomlabel',('randomlabel','labelgroup','location','label','bgimg'));
@@ -164,7 +164,6 @@ sub start_randomlabel {
 						     'height','texwidth');
 	if ($constructtag) {
 	    $result = &Apache::edit::rebuild_tag($token);
-	    $result.=&Apache::edit::handle_insert();
 	}
     }
     return $result;
@@ -268,12 +267,17 @@ sub end_bgimg {
 		&Apache::lonxml::debug("height $height_param");
 		&Apache::lonxml::debug("Width $width_param");
 		&Apache::lonxml::debug("Scale factors: $label_xscale $label_yscale");
-		my $dirty_width = $width_param + 5;
+		my $dirty_width = $width_param + $dirty_width_adjust;
+		my $x_offset    = -$dirty_width_adjust/2.0;
+		#
+		#  Somewhere here it looks like height_param and
+		#  width_param got backwards...
+		#
 		$result .= '\parbox{'.$dirty_width.'mm}{';
 		$result  .= " $src \n";
 		$result  .= '\setlength{\unitlength}{1mm}'."\n";
-		$result  .= '\begin{picture}('."$height_param,$width_param)";
-		$result  .= "(0,-$height_param)";
+		$result  .= '\begin{picture}('."$width_param,$height_param)";
+		$result  .= "($x_offset,-$height_param)";
 		$result  .= "\n";
 		$Apache::lonxml::debug = 0;
 
@@ -349,7 +353,6 @@ sub start_labelgroup {
 						     'TeXsize');
 	if ($constructtag) {
 	    $result = &Apache::edit::rebuild_tag($token);
-	    $result.=&Apache::edit::handle_insert();
 	}
     }
     return $result;
@@ -535,7 +538,6 @@ sub start_location {
 						    $safeeval,'x','y','value');
 	if ($constructtag) {
 	    $result = &Apache::edit::rebuild_tag($token);
-	    $result.=&Apache::edit::handle_insert();
 	}
     }
     $Apache::lonxml::debug = 0;
