@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # definition of tags that give a structure to a document
 #
-# $Id: structuretags.pm,v 1.380 2007/06/11 20:52:29 albertel Exp $
+# $Id: structuretags.pm,v 1.382 2007/06/22 20:42:20 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -880,14 +880,14 @@ sub end_problem {
 		    if ($Apache::lonhomework::type eq 'exam' and $allow_print_points==1) { $frontmatter .= '\fbox{\textit{'.$weight.' pt}}';}
 		}
 	    } else {
-		$frontmatter .= '\vskip 1mm\textit{Due date: '.$duedate.'} \\\\\\\\';
+		$frontmatter .= '\vskip 1mm\textit{Due date: '.$duedate.'} \\\\\\\\'.$startminipage;
 	    }
 	} else {
 	    if (not $env{'request.symb'} =~ m/\.page_/) {
 		$frontmatter .= $begin_doc.$toc_line;
 		if (($Apache::lonhomework::type eq 'exam') and ($allow_print_points==1)) { $frontmatter .= '\fbox{\textit{'.$weight.' pt}}';}
 	    } else {
-		$frontmatter .= '\vskip 1mm \\\\\\\\';
+		$frontmatter .= '\vskip 1mm \\\\\\\\'.$startminipage;
 	    }
 	}
 	$result =~ s/INSERTTEXFRONTMATTERHERE/$frontmatter/;
@@ -937,7 +937,7 @@ sub end_problem {
 		    if (not $env{'request.symb'} =~ m/\.page_/) {
 			$result .= $endminipage.'\end{document} ';
 		    } else {
-			$result .= '';
+			$result .= $endminipage;
 		    }
 		}
 	    }
