@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Create a course
 #
-# $Id: loncreatecourse.pm,v 1.101 2007/03/03 01:40:28 albertel Exp $
+# $Id: loncreatecourse.pm,v 1.101.2.1 2007/06/01 18:07:47 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -44,10 +44,11 @@ use LONCAPA;
 
 sub print_course_creation_page {
     my $r=shift;
-    my $crstype = 'Group';
-    if ($env{'form.phase'} eq 'courseone') {
-        $crstype = 'Course';
-    }
+    my $crstype = 'Course';
+#    my $crstype = 'Group';
+#    if ($env{'form.phase'} eq 'courseone') {
+#        $crstype = 'Course';
+#    }
     my $defdom=$env{'request.role.domain'};
     my %host_servers = &Apache::lonnet::get_servers($defdom,'library');
     my $course_home = '<select name="course_home" size="1">'."\n";
@@ -696,7 +697,7 @@ sub create_course {
 sub print_intro_page {
     my $r = shift;
     my $start_page =
-        &Apache::loncommon::start_page('Create a New Course or Group Space');
+        &Apache::loncommon::start_page('Create a New Course');
     my $crumbs = &Apache::lonhtmlcommon::breadcrumbs('Creation Options','Create_Course',undef,'Create_Courses');
     my $end_page =
         &Apache::loncommon::end_page();
@@ -707,11 +708,11 @@ sub print_intro_page {
                      short_description =>
     &mt('Create a new course by completing an online form.'),
                  },
-                   { internal_name => 'groupone',
-                     name => &mt('Create a single collaborative group space '),
-                     short_description =>
-    &mt('Create a new group space for non-course use by completing an online form .'),
-                 },
+#                   { internal_name => 'groupone',
+#                     name => &mt('Create a single collaborative group space '),
+#                     short_description =>
+#    &mt('Create a new group space for non-course use by completing an online form .'),
+#                 },
                    { internal_name => 'batchone',
                      name => &mt('Create courses/groups by uploading an attributes file'),
                      short_description =>
@@ -743,11 +744,11 @@ sub upload_batchfile {
     my $r = shift;
     my $start_page =
         &Apache::loncommon::start_page('Create a New Course or Group Space');
-    my $crumbs = &Apache::lonhtmlcommon::breadcrumbs('Upload Course/Group Attributes File','Create_Course',undef,'Create_Courses');
+    my $crumbs = &Apache::lonhtmlcommon::breadcrumbs('Upload Course Attributes File','Create_Course',undef,'Create_Courses');
     my $end_page =
         &Apache::loncommon::end_page();
     $r->print($start_page.$crumbs);
-    $r->print('<h3>'.&mt('Upload a courses or groups attributes file').'</h3>');
+    $r->print('<h3>'.&mt('Upload a courses attributes file').'</h3>');
     $r->print('<form name="batchcreate" method="post" '.
                 'enctype="multipart/form-data" action="/adm/createcourse">'.
               '<input type="file" name="coursecreatorxml" />'.
