@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Metadata display handler
 #
-# $Id: lonmeta.pm,v 1.195.2.1 2007/01/18 23:20:56 albertel Exp $
+# $Id: lonmeta.pm,v 1.208 2007/05/15 20:21:17 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -265,7 +265,7 @@ sub fieldnames {
          'correct'    => 'Material appears to be correct',
          'technical'  => 'Resource is technically correct', 
          'avetries'   => 'Average number of tries till solved',
-         'stdno'      => 'Total number of students who have worked on this problem',
+         'stdno'      => 'Statistics calculated for number of students',
          'difficulty' => 'Degree of difficulty',
          'disc'       => 'Degree of discrimination',
 	     'dependencies' => 'Resources used by this resource',
@@ -631,9 +631,16 @@ sub prettyinput {
                 if ($meta_options{$item}) {
                     push(@cur_values_inst,$item);
                 } else {
-                    $cur_values_stu .= $item.',';
+                    if ($item ne '') {
+                        $cur_values_stu .= $item.',';
+                    }
                 }
             }
+             $cur_values_stu =~ s/,$//;
+            my @key_order = sort(keys(%meta_options));
+            unshift(@key_order,'');
+            $meta_options{''} = 'Not specified';
+            $meta_options{'select_form_order'} = \@key_order;
         } else {
             $cur_values_stu = $value;
         }
@@ -645,6 +652,7 @@ sub prettyinput {
              || ($type eq 'author')||($type eq  'notes')
              || ($type eq  'abstract')|| ($type eq  'title')|| ($type eq  'standards')
              || (exists($env{$course_key.'.metadata.'.$type.'.added'}))) {
+            
             if ($values) {
                 if ($only_one) {
                     $output .= (&Apache::loncommon::select_form($cur_values_inst[0],'new_'.$type,%meta_options));
@@ -782,7 +790,6 @@ sub handler {
             %Apache::lonpublisher::metadatakeys=();
             my $result=&Apache::lonnet::getfile($fn);
             &Apache::lonpublisher::metaeval($result);
-            &Apache::lonnet::logthis("restricted is: ".$Apache::lonpublisher::metadatafields{'courserestricted'});
             if ((!$Apache::lonpublisher::metadatafields{'courserestricted'}) ||
                 ($env{'form.changecourse'} eq 'true')) {
                 &pre_select_course($r,$uri);
@@ -797,8 +804,10 @@ sub handler {
         &present_editable_metadata($r,$uri,'groups');    
     } elsif ($uri=~m|^/~|) { 
         # Construction space
-        $r->print(&Apache::loncommon::start_page('Edit Catalog nformation',
-						 undef,
+        $r->print(&Apache::loncommon::start_page('Edit Catalog Information',
+						"\n".'<script type="text/javascript">'."\n".
+                                                &Apache::loncommon::browser_and_searcher_javascript().
+                                                "\n".'</script>',
 						 {'domain' => $resdomain,}));
         &present_editable_metadata($r,$uri);
     } else {
@@ -1017,17 +1026,17 @@ sub print_dynamic_metadata {
             #
             # New assessment statistics
             $r->print('<h4>'.
-                      &mt('Detailed Assessment Statistical Data').
+                      &mt('Recent Detailed Assessment Statistical Data').
                       '</h4>');
             my $table = '<table cellspacing="2" border="0">'.
                 '<tr>'.
-                '<th>Course</th>'.
-                '<th>Section(s)</th>'.
-                '<th>Num Students</th>'.
-                '<th>Mean Tries</th>'.
-                '<th>Degree of Difficulty</th>'.
-                '<th>Degree of Discrimination</th>'.
-                '<th>Time of computation</th>'.
+                '<th>'.&mt('Course').'</th>'.
+                '<th>'.&mt('Section(s)').'</th>'.
+                '<th>'.&mt('Num Student').'s</th>'.
+                '<th>'.&mt('Mean Tries').'</th>'.
+                '<th>'.&mt('Degree of Difficulty').'</th>'.
+                '<th>'.&mt('Degree of Discrimination').'</th>'.
+                '<th>'.&mt('Time of computation').'</th>'.
                 '</tr>'.$/;
             foreach my $identifier (sort(keys(%{$dynmeta{'stats'}}))) {
                 my $data = $dynmeta{'stats'}->{$identifier};
@@ -1203,7 +1212,12 @@ ENDBOMBS
 <input type="submit" name="clearmsg" value="$clear" />
 ENDDEL
         } else {
-            $r->print('<a href="'.$disuri.'" />'.$goback.'</a>');
+            $r->print('<p><a href="'.$disuri.'">'.$goback.'</a></p>');
+	    if ($env{'form.clearmsg'}) {
+		my ($diruri) = ($disuri =~ m{(.*/)[^/]*});
+		$r->print('<p><a href="'.$diruri.'">'.
+			  &mt('Back To Directory').'</a></p>');
+	    }
 	}
 	$r->print('<br />'.$bombs);
     } else {
@@ -1243,9 +1257,6 @@ ENDDEL
 <h1>$displayfile</h1>
 <form method="post" action="" name="defaultmeta">
 ENDEDIT
-        $r->print('<script type="JavaScript">'.
-                  &Apache::loncommon::browser_and_searcher_javascript().
-                  '</script>');
         my %lt=&fieldnames($file_type);
 	my $output;
 	my @fields;
@@ -1301,8 +1312,8 @@ ENDEDIT
 		$Apache::lonpublisher::metadatafields{'owner'} =
 		    $env{'user.name'}.':'.$env{'user.domain'};
 	    }
-
 	    if ($Apache::lonpublisher::metadatafields{'courserestricted'} ne 'none') {
+
                 if ($file_type eq 'portfolio') {
 		    $r->print(&mt('Associated with course [_1]',
 		        '<strong><a href="'.$uri.'?changecourse=true">'.
@@ -1334,8 +1345,15 @@ ENDEDIT
         my $row_alt = 1;
         foreach my $field_name (@fields) {
             if (defined($env{'form.new_'.$field_name})) {
-                $Apache::lonpublisher::metadatafields{$field_name}=
-                    join(',',&Apache::loncommon::get_env_multiple('form.new_'.$field_name));
+                my @values = &Apache::loncommon::get_env_multiple('form.new_'.$field_name);
+                my $newvalue = '';
+                foreach my $item (@values) {
+                    if ($item ne '') {
+                        $newvalue .= $item.',';
+                    }
+                }
+                $newvalue =~ s/,$//; 
+                $Apache::lonpublisher::metadatafields{$field_name}=$newvalue;
             }
             if ($Apache::lonpublisher::metadatafields{'courserestricted'} ne 'none'
 		&& exists($env{$Apache::lonpublisher::metadatafields{'courserestricted'}.'.metadata.'.$field_name.'.options'})) {
@@ -1368,7 +1386,7 @@ ENDEDIT
             $r->print($result);
 	}
 	$r->print($output.'<br /><input type="submit" name="store" value="'.
-                  &mt('Store Catalog Information').'" />');
+                  &mt('Save Catalog Information').'" />');
 
 	if ($file_type eq 'portfolio' || $file_type eq 'groups') {
 	    my ($port_path,$group) = &get_port_path_and_group($uri);
@@ -1502,22 +1520,14 @@ sub store_portfolio_metadata {
 
 sub update_metadata_table {
     my ($uri) = @_;
-    my ($group,$file_name);
-    my ($udom,$uname,$remainder) =
-        ($uri=~m -^/+(?:uploaded|editupload)/+($match_domain)/+($match_name)/+(.*)$-);
-
-    if ($remainder =~ /^groups\/(\w+)\/portfolio(\/.+)$/) {
-        $group = $1;
-        $file_name = $2;
-    } elsif ($remainder =~ /^portfolio(\/.+)$/) {
-        $file_name = $1;
-    }
+    my ($type,$udom,$uname,$file_name,$group) =
+	&Apache::lonnet::parse_portfolio_url($uri);
     $file_name =~ s/\.meta$//;
     my $current_permissions =
         &Apache::lonnet::get_portfile_permissions($udom,$uname);
     my %access_controls =
         &Apache::lonnet::get_access_controls($current_permissions,$group,
-                                             $group.$file_name);
+                                             $file_name);
     my $access_hash = $access_controls{$file_name};
     my $available = 0;
     if (ref($access_hash) eq 'HASH') {
