@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Routines for messaging
 #
-# $Id: lonmsg.pm,v 1.195 2006/12/28 19:43:24 raeburn Exp $
+# $Id: lonmsg.pm,v 1.209 2007/05/10 00:50:52 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -28,6 +28,37 @@
 
 package Apache::lonmsg;
 
+=pod
+
+=head1 NAME
+
+Apache::lonmsg: supports internal messaging
+
+=head1 SYNOPSIS
+
+lonmsg provides routines for sending messages.
+
+Right now, this document will cover just how to send a message, since
+it is likely you will not need to programmatically read messages,
+since lonmsg already implements that functionality.
+
+The routines used to package messages and unpackage messages are not
+only used by lonmsg when creating/extracting messages for LON-CAPA's
+internal messaging system, but also by lonnotify.pm which is available
+for use by Domain Coordinators to broadcast standard e-mail to specified
+users in their domain.  The XML packaging used in the two cases is very
+similar.  The differences are the use of <recuser>$uname</recuser> and
+<recdomain>$udom</recdomain> in stored internal messages, compared
+with <recipient username="$uname:$udom">$email</recipient> in stored
+Domain Coordinator e-mail for the storage of information about
+recipients of the message/e-mail.
+
+=head1 FUNCTIONS
+
+=over 4
+
+=cut
+
 use strict;
 use Apache::lonnet;
 use HTML::TokeParser();
@@ -47,7 +78,7 @@ use LONCAPA qw(:DEFAULT :match);
 
 sub packagemsg {
     my ($subject,$message,$citation,$baseurl,$attachmenturl,
-	$recuser,$recdomain,$msgid,$type,$crsmsgid,$symb,$error)=@_;
+	$recuser,$recdomain,$msgid,$type,$crsmsgid,$symb,$error,$recipid)=@_;
     $message =&HTML::Entities::encode($message,'<>&"');
     $citation=&HTML::Entities::encode($citation,'<>&"');
     $subject =&HTML::Entities::encode($subject,'<>&"');
@@ -57,23 +88,7 @@ sub packagemsg {
     #remove machine specification
     $attachmenturl =~ s|^http://[^/]+/|/|;
     $attachmenturl =&HTML::Entities::encode($attachmenturl,'<>&"');
-    my $course_context;
-    if (defined($env{'form.replyid'})) {
-        my ($sendtime,$shortsubj,$fromname,$fromdomain,$count,$origcid)=
-                   split(/\:/,&unescape($env{'form.replyid'}));
-        $course_context = $origcid;
-    }
-    foreach my $key (keys(%env)) {
-        if ($key=~/^form\.(rep)?rec\_(.*)$/) {
-            my ($sendtime,$shortsubj,$fromname,$fromdomain,$count,$origcid) =
-                                    split(/\:/,&unescape($2));
-            $course_context = $origcid;
-            last;
-        }
-    }
-    unless(defined($course_context)) {
-        $course_context = $env{'request.course.id'};
-    }
+    my $course_context = &get_course_context();
     my $now=time;
     my $msgcount = &get_uniq();
     unless(defined($msgid)) {
@@ -136,7 +151,7 @@ sub packagemsg {
     }
     if (defined($symb)) {
         $result.= '<symb>'.$symb.'</symb>';
-        if (defined($course_context)) {
+        if ($course_context ne '') {
             if ($course_context eq $env{'request.course.id'}) {
                 my $resource_title = &Apache::lonnet::gettitle($symb);
                 if (defined($resource_title)) {
@@ -145,9 +160,44 @@ sub packagemsg {
             }
         }
     }
+    if (defined($recipid)) {
+        $result.= '<recipid>'.$recipid.'</recipid>';
+    }
+    if ($env{'form.can_reply'} eq 'N') {
+        $result .= '<noreplies>1</noreplies>';
+    }
+    if ($env{'form.reply_to_addr'}) {
+        my ($replytoname,$replytodom) = split(/:/,$env{'form.reply_to_addr'});
+        if (!($replytoname eq $env{'user.name'} && $replytodom eq $env{'user.domain'})) {
+            if (&Apache::lonnet::homeserver($replytoname,$replytodom) ne 'no_host') {
+                $result .= '<replytoaddr>'.$env{'form.reply_to_addr'}.'</replytoaddr>';
+            }
+        }
+    }
     return ($msgid,$result);
 }
 
+sub get_course_context {
+    my $course_context;
+    if (defined($env{'form.replyid'})) {
+        my ($sendtime,$shortsubj,$fromname,$fromdomain,$count,$origcid)=
+                   split(/\:/,&unescape($env{'form.replyid'}));
+        $course_context = $origcid;
+    }
+    foreach my $key (keys(%env)) {
+        if ($key=~/^form\.(rep)?rec\_(.*)$/) {
+            my ($sendtime,$shortsubj,$fromname,$fromdomain,$count,$origcid) =
+                                    split(/\:/,&unescape($2));
+            $course_context = $origcid;
+            last;
+        }
+    }
+    if ($course_context eq '') {
+        $course_context = $env{'request.course.id'};
+    }
+    return $course_context;
+}
+
 # ================================================== Unpack message into a hash
 
 sub unpackagemsg {
@@ -249,18 +299,18 @@ sub sendnotification {
     my ($to,$touname,$toudom,$subj,$crit,$text,$msgid)=@_;
     my $sender=$env{'environment.firstname'}.' '.$env{'environment.lastname'};
     unless ($sender=~/\w/) { 
-	$sender=$env{'user.name'}.'@'.$env{'user.domain'};
+	$sender=$env{'user.name'}.':'.$env{'user.domain'};
     }
     my $critical=($crit?' critical':'');
+
     $text=~s/\&lt\;/\</gs;
     $text=~s/\&gt\;/\>/gs;
-    $text=~s/\<\/*[^\>]+\>//gs;
     my $url='http://'.
-      $Apache::lonnet::hostname{&Apache::lonnet::homeserver($touname,$toudom)}.
+	&Apache::lonnet::hostname(&Apache::lonnet::homeserver($touname,$toudom)).
       '/adm/email?username='.$touname.'&domain='.$toudom;
     my ($sendtime,$shortsubj,$fromname,$fromdomain,$status,$fromcid,
         $symb,$error) = &Apache::lonmsg::unpackmsgid($msgid);
-    my $coursetext;
+    my ($coursetext,$body,$bodybegin,$bodysubj,$bodyend);
     if ($fromcid ne '') {
         $coursetext = "\n".&mt('Course').': ';
         if ($env{'course.'.$fromcid.'.description'} ne '') {
@@ -273,14 +323,17 @@ sub sendnotification {
         }
         $coursetext .= "\n\n";
     }
-    my $body = $coursetext. 
-               &mt('You received a'.$critical.' message from [_1] in LON-CAPA.',$sender).' '.&mt('The subject is 
+    my @recipients = split(/,/,$to);
+    $bodybegin = $coursetext. 
+               &mt('You received a'.$critical.' message from [_1] in LON-CAPA.',$sender).' ';
+    $bodysubj = &mt('The subject is 
 
  [_1]
 
 ',$subj)."\n".
 '=== '.&mt('Excerpt')." ============================================================
-$text
+";
+    $bodyend = "
 ========================================================================
 
 ".&mt('Use 
@@ -288,7 +341,44 @@ $text
  [_1]
 
 to access the full message.',$url);
-    &sendemail($to,'New'.$critical.' message from '.$sender,$body);
+    my %userenv = &Apache::lonnet::get('environment',['notifywithhtml'],$toudom,$touname);
+    my $subject = &mt("'New' $critical message from ").$sender;
+ 
+    my ($blocked,$blocktext);
+    if (!$crit) {
+        my %setters;
+        my ($startblock,$endblock) = 
+            &Apache::loncommon::blockcheck(\%setters,'com',$touname,$toudom);
+        if ($startblock && $endblock) {
+            $blocked = 1;
+            my $showstart = &Apache::lonlocal::locallocaltime($startblock);
+            my $showend = &Apache::lonlocal::locallocaltime($endblock);
+            $blocktext = &mt('LON-CAPA messages sent to you between [_1] and [_2] will be inaccessible until the end of this time period, because you are a student in a course with an active communications block.',$showstart,$showend);
+        }
+    }
+    if ($userenv{'notifywithhtml'} ne '') {
+        my @htmlexcerpt = split(/,/,$userenv{'notifywithhtml'});
+        foreach my $addr (@recipients) {
+            if ($blocked) {
+                $body = $bodybegin."\n".$blocktext."\n".$bodyend;
+            } else {
+                my $sendtext = $text;
+                if (!grep/^\Q$addr\E/,@htmlexcerpt) {
+                    $sendtext =~ s/\<\/*[^\>]+\>//gs;
+                }
+                $body = $bodybegin.$bodysubj.$sendtext.$bodyend;
+            }
+            &sendemail($addr,$subject,$body);
+        }
+    } else {
+        if ($blocked) {
+            $body = $bodybegin."\n".$blocktext."\n".$bodyend;
+        } else {
+            $text =~ s/\<\/*[^\>]+\>//gs;
+            $body = $bodybegin.$bodysubj.$text.$bodyend;
+        }
+        &sendemail($to,$subject,$body);
+    }
 }
 # ============================================================= Check for email
 
@@ -399,13 +489,17 @@ sub store_instructor_comment {
     my $cdom = $env{'course.'.$cid.'.domain'};
     my $subject= &mt('Record').' ['.$uname.':'.$udom.']';
     my $result = &user_normal_msg_raw($cnum,$cdom,$subject,$msg);
+    if ($result eq 'ok' || $result eq 'con_delayed') {
+        
+    }
     return $result;
 }
 
 # ================================================== Critical message to a user
 
 sub user_crit_msg_raw {
-    my ($user,$domain,$subject,$message,$sendback,$toperm,$sentmessage)=@_;
+    my ($user,$domain,$subject,$message,$sendback,$toperm,$sentmessage,
+        $nosentstore,$recipid)=@_;
 # Check if allowed missing
     my ($status,$packed_message);
     my $msgid='undefined';
@@ -413,7 +507,9 @@ sub user_crit_msg_raw {
     my $text=$message;
     my $homeserver=&Apache::lonnet::homeserver($user,$domain);
     if ($homeserver ne 'no_host') {
-       ($msgid,$packed_message)=&packagemsg($subject,$message);
+       ($msgid,$packed_message)=&packagemsg($subject,$message,undef,undef,
+                                  undef,undef,undef,undef,undef,undef,undef,
+                                  undef,$recipid);
        if ($sendback) { $packed_message.='<sendback>true</sendback>'; }
        $status=&Apache::lonnet::critical(
            'put:'.$domain.':'.$user.':critical:'.
@@ -422,7 +518,7 @@ sub user_crit_msg_raw {
         if (defined($sentmessage)) {
             $$sentmessage = $packed_message;
         }
-        if ($env{'request.course.id'} eq '') {
+        if (!$nosentstore) {
             (undef,my $packed_message_no_citation) =
             &packagemsg($subject,$message,undef,undef,undef,$user,$domain,
                         $msgid);
@@ -459,9 +555,10 @@ sub user_crit_msg_raw {
 
 =pod
 
-=item * B<user_crit_msg($user, $domain, $subject, $message, $sendback)>: Sends
-    a critical message $message to the $user at $domain. If $sendback is true,
-    a reciept will be sent to the current user when $user recieves the message.
+=item * B<user_crit_msg($user, $domain, $subject, $message, $sendback, $nosentstore,$recipid)>: 
+    Sends a critical message $message to the $user at $domain.  If $sendback
+    is true,  a receipt will be sent to the current user when $user receives 
+    the message.
 
     Additionally it will check if the user has a Forwarding address
     set, and send the message to that address instead
@@ -474,7 +571,8 @@ sub user_crit_msg_raw {
 =cut
 
 sub user_crit_msg {
-    my ($user,$domain,$subject,$message,$sendback,$toperm,$sentmessage)=@_;
+    my ($user,$domain,$subject,$message,$sendback,$toperm,$sentmessage,
+        $nosentstore,$recipid)=@_;
     my @status;
     my %userenv = &Apache::lonnet::get('environment',['msgforward'],
                                        $domain,$user);
@@ -484,12 +582,13 @@ sub user_crit_msg {
 	 my ($forwuser,$forwdomain)=split(/\:/,$addr);
          push(@status,
 	      &user_crit_msg_raw($forwuser,$forwdomain,$subject,$message,
-				 $sendback,$toperm,$sentmessage));
+				 $sendback,$toperm,$sentmessage,$nosentstore,
+                                 $recipid));
        }
     } else { 
 	push(@status,
 	     &user_crit_msg_raw($user,$domain,$subject,$message,$sendback,
-				$toperm,$sentmessage));
+				$toperm,$sentmessage,$nosentstore,$recipid));
     }
     if (wantarray) {
 	return @status;
@@ -503,14 +602,24 @@ sub user_crit_received {
     my $msgid=shift;
     my %message=&Apache::lonnet::get('critical',[$msgid]);
     my %contents=&unpackagemsg($message{$msgid},1);
+    my $destname = $contents{'sendername'};
+    my $destdom = $contents{'senderdomain'};
+    if ($contents{'replytoaddr'}) {
+        my ($repname,$repdom) = split(/:/,$contents{'replytoaddr'});
+        if (&Apache::lonnet::homeserver($repname,$repdom) ne 'no_host') {
+            $destname = $repname;
+            $destdom = $repdom;    
+        }
+    }
     my $status='rec: '.($contents{'sendback'}?
-     &user_normal_msg($contents{'sendername'},$contents{'senderdomain'},
-                     &mt('Receipt').': '.$env{'user.name'}.' '.&mt('at').' '.$env{'user.domain'}.', '.$contents{'subject'},
-                     &mt('User').' '.$env{'user.name'}.' '.&mt('at').' '.$env{'user.domain'}.
-                     ' acknowledged receipt of message'."\n".'   "'.
-                     $contents{'subject'}.'"'."\n".&mt('dated').' '.
-                     $contents{'time'}.".\n"
-                     ):'no msg req');
+     &user_normal_msg($destname,$destdom,&mt('Receipt').': '.$env{'user.name'}.
+                      ' '.&mt('at').' '.$env{'user.domain'}.', '.
+                      $contents{'subject'},&mt('User').' '.$env{'user.name'}.
+                      ' '.&mt('at').' '.$env{'user.domain'}.
+                      ' acknowledged receipt of message'."\n".'   "'.
+                      $contents{'subject'}.'"'."\n".&mt('dated').' '.
+                      $contents{'time'}.".\n"
+                      ):'no msg req');
     $status.=' trans: '.
      &Apache::lonnet::put(
      'nohist_email',{$contents{'msgid'} => $message{$msgid}});
@@ -528,7 +637,7 @@ sub user_crit_received {
 sub user_normal_msg_raw {
     my ($user,$domain,$subject,$message,$citation,$baseurl,$attachmenturl,
         $toperm,$currid,$newid,$sentmessage,$crsmsgid,$symb,$restitle,
-        $error)=@_;
+        $error,$nosentstore,$recipid)=@_;
 # Check if allowed missing
     my ($status,$packed_message);
     my $msgid='undefined';
@@ -539,7 +648,7 @@ sub user_normal_msg_raw {
        ($msgid,$packed_message)=
 	                 &packagemsg($subject,$message,$citation,$baseurl,
                                      $attachmenturl,$user,$domain,$currid,
-                                     undef,$crsmsgid,$symb,$error);
+                                     undef,$crsmsgid,$symb,$error,$recipid);
 
 # Store in user folder
        $status=&Apache::lonnet::critical(
@@ -549,13 +658,8 @@ sub user_normal_msg_raw {
 # Save new message received time
        &Apache::lonnet::put
                          ('email_status',{'recnewemail'=>time},$domain,$user);
-# Into sent-mail folder unless a broadcast message or critical message
-       unless (($env{'request.course.id'}) && 
-               (($env{'form.sendmode'} eq 'group')  || 
-               (($env{'form.critmsg'}) || ($env{'form.sendbck'})) &&
-               (&Apache::lonnet::allowed('srm',$env{'request.course.id'})
-		|| &Apache::lonnet::allowed('srm',$env{'request.course.id'}.
-					    '/'.$env{'request.course.sec'})))) {
+# Into sent-mail folder if sent mail storage required
+       if (!$nosentstore) {
            (undef,my $packed_message_no_citation) =
                &packagemsg($subject,$message,undef,$baseurl,$attachmenturl,
                            $user,$domain,$currid,undef,$crsmsgid,$symb,$error);
@@ -563,31 +667,28 @@ sub user_normal_msg_raw {
                &store_sent_mail($msgid,$packed_message_no_citation);
            }
        }
-    } else {
-       $status='no_host';
-    }
-    if (defined($newid)) {
-        $$newid = $msgid;
-    }
-    if (defined($sentmessage)) {
-        $$sentmessage = $packed_message;
-    }
-
+       if (ref($newid) eq 'SCALAR') {
+	   $$newid = $msgid;
+       }
+       if (ref($sentmessage) eq 'SCALAR') {
+	   $$sentmessage = $packed_message;
+       }
 # Notifications
-    my %userenv = &Apache::lonnet::get('environment',['notification',
-                                                      'permanentemail'],
-                                       $domain,$user);
-    if ($userenv{'notification'}) {
-	&sendnotification($userenv{'notification'},$user,$domain,$subject,0,
-			  $text,$msgid);
-    }
-    if ($toperm && $userenv{'permanentemail'}) {
-	&sendnotification($userenv{'permanentemail'},$user,$domain,$subject,0,
-			  $text,$msgid);
-    }
-    &Apache::lonnet::log($env{'user.domain'},$env{'user.name'},
-                         $env{'user.home'},
-      'Sending '.$msgid.' to '.$user.' at '.$domain.' with status: '.$status);
+       my %userenv = &Apache::loncommon::getemails($user,$domain);
+       if ($userenv{'notification'}) {
+	   &sendnotification($userenv{'notification'},$user,$domain,$subject,0,
+			     $text,$msgid);
+       }
+       if ($toperm && $userenv{'permanentemail'}) {
+	   &sendnotification($userenv{'permanentemail'},$user,$domain,$subject,0,
+			     $text,$msgid);
+       }
+       &Apache::lonnet::log($env{'user.domain'},$env{'user.name'},
+			    $env{'user.home'},
+			    'Sending '.$msgid.' to '.$user.' at '.$domain.' with status: '.$status);
+   } else {
+       $status='no_host';
+   }
     return $status;
 }
 
@@ -596,44 +697,106 @@ sub user_normal_msg_raw {
 =pod
 
 =item * B<user_normal_msg($user, $domain, $subject, $message, $citation,
-       $baseurl, $attachmenturl, $toperm, $sentmessage, $symb, $restitle, $error)>:
+       $baseurl, $attachmenturl, $toperm, $sentmessage, $symb, $restitle,
+       $error,$nosentstore,$recipid)>:
  Sends a message to the  $user at $domain, with subject $subject and message $message.
 
+    Additionally it will check if the user has a Forwarding address
+    set, and send the message to that address instead
+
+    returns
+      - in array context a list of results for each message that was sent
+      - in scalar context a space seperated list of results for each
+           message sent
+
 =cut
 
 sub user_normal_msg {
     my ($user,$domain,$subject,$message,$citation,$baseurl,$attachmenturl,
-	$toperm,$sentmessage,$symb,$restitle,$error)=@_;
-    my $status='';
+	$toperm,$sentmessage,$symb,$restitle,$error,$nosentstore,$recipid)=@_;
+    my @status;
     my %userenv = &Apache::lonnet::get('environment',['msgforward'],
                                        $domain,$user);
     my $msgforward=$userenv{'msgforward'};
     if ($msgforward) {
         foreach (split(/\,/,$msgforward)) {
 	    my ($forwuser,$forwdomain)=split(/\:/,$_);
-	    $status.=
+	    push(@status,
 	        &user_normal_msg_raw($forwuser,$forwdomain,$subject,$message,
 				     $citation,$baseurl,$attachmenturl,$toperm,
-				     undef,undef,$sentmessage,undef,$symb,$restitle,$error).' ';
+				     undef,undef,$sentmessage,undef,$symb,
+                                     $restitle,$error,$nosentstore,$recipid));
         }
     } else {
-	$status=&user_normal_msg_raw($user,$domain,$subject,$message,
+	push(@status,&user_normal_msg_raw($user,$domain,$subject,$message,
 				     $citation,$baseurl,$attachmenturl,$toperm,
-				     undef,undef,$sentmessage,undef,$symb,$restitle,$error);
+				     undef,undef,$sentmessage,undef,$symb,
+                                     $restitle,$error,$nosentstore,$recipid));
     }
+    if (wantarray) {
+        return @status;
+    }
+    return join(' ',@status);
+}
+
+sub process_sent_mail {
+    my ($msgsubj,$subj_prefix,$numsent,$stamp,$msgname,$msgdom,$msgcount,$context,$pid,$savemsg,$recusers,$recudoms,$baseurl,$attachmenturl,$symb,$error,$senderuname,$senderdom,$senderhome) = @_;
+    my $sentsubj;
+    if ($numsent > 1) {
+        $sentsubj = $subj_prefix.' ('.$numsent.' sent) '.$msgsubj;
+    } else {
+        if ($subj_prefix) {
+            $sentsubj = $subj_prefix.' ';
+        }
+        $sentsubj .= $msgsubj;
+    }
+    $sentsubj = &HTML::Entities::encode($sentsubj,'<>&"');
+    my $sentmsgid = 
+        &buildmsgid($stamp,$sentsubj,$msgname,$msgdom,$msgcount,$context,$pid);
+    (undef,my $sentmessage) =
+        &packagemsg($msgsubj,$savemsg,undef,$baseurl,$attachmenturl,$recusers,
+                    $recudoms,$sentmsgid,undef,undef,$symb,$error);
+    my $status = &store_sent_mail($sentmsgid,$sentmessage,$senderuname,
+                                  $senderdom,$senderhome);
     return $status;
 }
 
 sub store_sent_mail {
-    my ($msgid,$message) = @_;
+    my ($msgid,$message,$senderuname,$senderdom,$senderhome) = @_;
+    if ($senderuname eq '') {
+        $senderuname = $env{'user.name'};
+    }
+    if ($senderdom eq '') {
+        $senderdom = $env{'user.domain'};
+    }
+    if ($senderhome eq '') {
+        $senderhome = $env{'user.home'};
+    }
     my $status =' '.&Apache::lonnet::critical(
-               'put:'.$env{'user.domain'}.':'.$env{'user.name'}.
-                                          ':nohist_email_sent:'.
-               &escape($msgid).'='.
-               &escape($message),$env{'user.home'});
+               'put:'.$senderdom.':'.$senderuname.':nohist_email_sent:'.
+               &escape($msgid).'='.&escape($message),$senderhome);
     return $status;
 }
 
+sub store_recipients {
+    my ($subject,$sendername,$senderdom,$reciphash) = @_;
+    my $context = &get_course_context();
+    my $now = time();
+    my $msgcount = &get_uniq();
+    my $recipid =
+        &buildmsgid($now,$subject,$sendername,$senderdom,$msgcount,$context,$$);
+    my %recipinfo = (
+                         $recipid => $reciphash,
+                    );
+    my $status = &Apache::lonnet::put('nohist_emailrecip',\%recipinfo,
+                                      $senderdom,$sendername); 
+    if ($status eq 'ok') {
+        return ($recipid,$status);
+    } else {
+        return (undef,$status);
+    }
+}
+
 # =============================================================== Folder suffix
 
 sub foldersuffix {
@@ -666,6 +829,102 @@ sub get_user_folders {
     return %userfolders;
 }
 
+sub secapply {
+    my $rec=shift;
+    my $defaultflag=shift;
+    $rec=~s/\s+//g;
+    $rec=~s/\@/\:/g;
+    my ($adr,$sections_or_groups)=($rec=~/^([^\(]+)\(([^\)]+)\)/);
+    if ($sections_or_groups) {
+	foreach my $item (split(/\;/,$sections_or_groups)) {
+            if (($item eq $env{'request.course.sec'}) ||
+                ($defaultflag && ($item eq '*'))) {
+                return $adr; 
+            } elsif ($env{'request.course.groups'}) {
+                my @usersgroups = split(/:/,$env{'request.course.groups'});
+                if (grep(/^\Q$item\E$/,@usersgroups)) {
+                    return $adr;
+                }
+            } 
+        }
+    } else {
+       return $rec;
+    }
+    return '';
+}
+
+=pod 
+
+=item * B<decide_receiver($feedurl,$author,$question,$course,$policy,$defaultflag)>:
+
+Arguments
+  $feedurl - /res/ url of resource (only need if $author is true)
+  $author,$question,$course,$policy - all true/false parameters
+    if true will attempt to find the addresses of user that should receive
+    this type of feedback (author - feedback to author of resource $feedurl,
+    $question 'Resource Content Questions', $course 'Course Content Question',
+    $policy 'Course Policy')
+    (Additionally it also checks $env for whether the corresponding form.<name>
+    element exists, for ease of use in a html response context)
+   
+  $defaultflag - (internal should be left blank) if true gather addresses 
+                 that aren't for a section even if I have a section
+                 (used for reccursion internally, first we look for
+                 addresses for our specific section then we recurse
+                 and look for non section addresses)
+
+Returns
+  $typestyle - string of html text, describing what addresses were found
+  %to - a hash, which keys are addresses of users to send messages to
+        the keys will look like   name:domain
+
+=cut
+
+sub decide_receiver {
+    my ($feedurl,$author,$question,$course,$policy,$defaultflag) = @_;
+    &Apache::lonenc::check_decrypt(\$feedurl);
+    my $typestyle='';
+    my %to=();
+    if ($env{'form.discuss'} eq 'author' ||$author) {
+	$typestyle.='Submitting as Author Feedback<br />';
+	$feedurl=~ m{^/res/($LONCAPA::domain_re)/($LONCAPA::username_re)/};
+	$to{$2.':'.$1}=1;
+    }
+    my $cid = $env{'request.course.id'};
+    if ($env{'form.discuss'} eq 'question' ||$question) {
+	$typestyle.=&mt('Submitting as Question').'<br />';
+	foreach my $item (split(/\,/,$env{'course.'.$cid.'.question.email'})) {
+	    my $rec=&secapply($item,$defaultflag);
+	    if ($rec) { $to{$rec}=1; }
+	} 
+    }
+    if ($env{'form.discuss'} eq 'course' ||$course) {
+	$typestyle.=&mt('Submitting as Comment').'<br />';
+	foreach my $item (split(/\,/,$env{'course.'.$cid.'.comment.email'})) {
+	    my $rec=&secapply($item,$defaultflag);
+	    if ($rec) { $to{$rec}=1; }
+	} 
+    }
+    if ($env{'form.discuss'} eq 'policy' ||$policy) {
+	$typestyle.=&mt('Submitting as Policy Feedback').'<br />';
+	foreach my $item (split(/\,/,$env{'course.'.$cid.'.policy.email'})) {
+	    my $rec=&secapply($item,$defaultflag);
+	    if ($rec) { $to{$rec}=1; }
+	} 
+    }
+    if ((scalar(%to) eq '0') && (!$defaultflag)) {
+	($typestyle,%to)=
+	    &decide_receiver($feedurl,$author,$question,$course,$policy,1);
+    }
+    return ($typestyle,%to);
+}
+
+=pod
+
+=back
+
+=cut
+
 1;
 __END__
 
