@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # portfolio browser
 #
-# $Id: portfolio.pm,v 1.184 2007/06/11 21:29:44 albertel Exp $
+# $Id: portfolio.pm,v 1.184.2.1 2007/07/10 20:57:10 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1733,7 +1733,8 @@ ENDSMP
                     fileList = fileList + document.forms.checkselect.currentpath.value + document.forms.checkselect[i].value + "," ;
                 }
             }
-            opener.document.forms.lonhomework.$env{'form.fieldname'}.value=fileList;
+            var hwfield = opener.document.getElementsByName('$env{'form.fieldname'}');
+            hwfield[0].value = fileList;
             self.close();
         }
         </script>
