@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonmetadata.pm,v 1.21 2007/05/12 23:24:56 albertel Exp $
+# $Id: lonmetadata.pm,v 1.22 2007/06/15 23:02:09 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1000,6 +1000,10 @@ sub portfolio_metadata {
                 }
             }
         } # End of ($token->[0] eq 'S')
+
+	if (!exists($metacache{'domain'})) {
+	    $metacache{'domain'} = $dom;
+	}
     }
     return (\%metacache,$metacache{'courserestricted'},\%addedfields);
 }
