@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Publication Handler
 #
-# $Id: lonpublisher.pm,v 1.224 2007/05/02 01:34:23 albertel Exp $
+# $Id: lonpublisher.pm,v 1.225 2007/06/18 20:30:32 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -494,11 +494,15 @@ sub get_subscribed_hosts {
     $target=~/(.*)\/([^\/]+)$/;
     my $srcf=$2;
     opendir(DIR,$1);
+    # cycle through listed files, subscriptions used to exist
+    # as "filename.lonid"
     while ($filename=readdir(DIR)) {
 	if ($filename=~/\Q$srcf\E\.($match_lonid)$/) {
 	    my $subhost=$1;
-	    if (($subhost ne 'meta' && $subhost ne 'subscription' &&
-		 $subhost ne 'tmp') &&
+	    if (($subhost ne 'meta' 
+		 && $subhost ne 'subscription' 
+		 && $subhost ne 'meta.subscription'
+		 && $subhost ne 'tmp') &&
                 ($subhost ne $Apache::lonnet::perlvar{'lonHostID'})) {
 		push(@subscribed,$subhost);
 	    }
