@@ -1,5 +1,5 @@
 # Handler for parsing text upload problem descriptions into .problems
-# $Id: testbankimport.pm,v 1.11 2006/12/06 22:22:39 albertel Exp $
+# $Id: testbankimport.pm,v 1.12 2007/05/02 01:34:23 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -393,7 +393,7 @@ function createWin() {
     newWindow.document.write("<td><h3>Location: <tt>$fullpath</tt></h3><h3>New Directory</h3></td></tr>\\n")
     newWindow.document.write("<tr><td width='2'>&nbsp;</td><td width='3'>&nbsp;</td>\\n")
     newWindow.document.write("<td><form name='fileaction' action='/adm/cfile' method='post'>\\n")
-    newWindow.document.write("<font face='arial,helvetica,sans-serif'>Enter the name of the new directory where you will store the converted testbank questions<br /><br />")
+    newWindow.document.write("<font face='arial,helvetica,sans-serif'>Enter the name of the new directory where you will save the converted testbank questions<br /><br />")
     newWindow.document.write("<input type='hidden' name='filename' value='$fullpath'>")   
     newWindow.document.write("<input type='hidden' name='action' value='newdir'>")
     newWindow.document.write("<input type='hidden' name='callingmode' value='testbank'>")
@@ -470,7 +470,7 @@ Five steps are involved in the import process.
     $r->print(qq|</li>
          <li>Provide information about the question format - i.e.,  question numbering style, and the number of blocks of questions of each question type.</li>
          <li>Provide information about the questions in each block, including question type, start and end question numbers for each block, and foil labelling style and answer format where required.</li>
-         <li>Create a new directory where you will store the converted testbank questions.</li> 
+         <li>Create a new directory where you will save the converted testbank questions.</li> 
          <li>Complete the import of questions to the selected pool.</li>
         </ol>
         </font>
@@ -1030,7 +1030,7 @@ END_OF_ONE
        <td width='30' align='top'><img src='/res/adm/pages/bl_step4.gif'>
        </td>
        <td width='100%' align='left'>&nbsp;&nbsp;
-        <font size='+1' face='arial,helvetica,sans-serif'><b>Create a directory to store your testbank questions.</b></font>
+        <font size='+1' face='arial,helvetica,sans-serif'><b>Create a directory to save your testbank questions.</b></font>
        </td>
       </tr>
       <tr>
@@ -1040,7 +1040,7 @@ END_OF_ONE
        <td>&nbsp;</td>
        <td>
         <font face='Arial,Helvetica,sans-serif'>
-Please choose a destination LON-CAPA directory in which to store your uploaded questions.&nbsp;&nbsp;
+Please choose a destination LON-CAPA directory in which to save your uploaded questions.&nbsp;&nbsp;
        <input type="button" name="createdir" value="Create Directory" onClick="javascript:createWin()"><input type="hidden" name="newdir" value=""></font></td>
       </tr>
       <tr>
