@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # <script> definiton
 #
-# $Id: scripttag.pm,v 1.140 2007/01/23 21:28:41 albertel Exp $
+# $Id: scripttag.pm,v 1.141 2007/06/11 20:52:40 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -128,16 +128,17 @@ sub start_script {
 
 	    $uname =~s/\W//g;
 	    $udom  =~s/\W//g;
-	    $result.="<script type=\"text/javascript\">
+	    my $script_var ="<script type=\"text/javascript\">
 // <![CDATA[
     function LONCAPA_scriptvars_".$uname."_".$udom."_"."$Apache::lonxml::curdepth() {newWindow=open('','new_W','width=500,height=500,scrollbars=1,resizable=yes');newWindow.$windowopen;newWindow.document.writeln('$start_page<pre>";
 	    my $listing=&Apache::run::dump($target,$safeeval);
 	    $listing=~s/\\/\\\\/g;
 	    $listing=~s/\'/\\\'/g;
-	    $result.=$listing;
-	    $result.= "<\\/pre>$end_page');newWindow.document.close();newWindow.focus()}
+	    $script_var.=$listing;
+	    $script_var.= "<\\/pre>$end_page');newWindow.document.close();newWindow.focus()}
 // ]]>
 </script><a href=\"javascript:LONCAPA_scriptvars_".$uname."_".$udom."_$Apache::lonxml::curdepth();void(0);\">Script Vars</a><br />";
+	    &Apache::lonxml::add_script_result($script_var);
 	}
     } elsif ($target eq "edit" ) {
       #&Apache::run::run($bodytext,$safeeval);
